"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const uuid_1 = require("uuid");
const base_1 = require("./base");
const task_1 = require("./task");
const result_1 = require("./result");
class TaskMessage {
    constructor(headers, properties, body, sentEvent) {
        this.headers = headers;
        this.properties = properties;
        this.body = body;
        this.sentEvent = sentEvent;
    }
}
class Client extends base_1.default {
    constructor() {
        super(...arguments);
        this.taskProtocols = {
            1: this.asTaskV1,
            2: this.asTaskV2,
        };
    }
    get createTaskMessage() {
        return this.taskProtocols[this.conf.TASK_PROTOCOL];
    }
    sendTaskMessage(taskName, message, options = {}) {
        const { headers, properties, body /*, sentEvent */ } = message;
        const exchange = "";
        // exchangeType = 'direct';
        // const serializer = 'json';
        this.isReady().then(() => {
            var _a, _b, _c, _d;
            return this.broker.publish(body, (_b = (_a = options) === null || _a === void 0 ? void 0 : _a.exchange, (_b !== null && _b !== void 0 ? _b : exchange)), (_d = (_c = options) === null || _c === void 0 ? void 0 : _c.routingKey, (_d !== null && _d !== void 0 ? _d : this.conf.CELERY_QUEUE)), headers, properties);
        });
    }
    asTaskV2(taskId, taskName, args, kwargs) {
        const message = {
            headers: {
                lang: "js",
                task: taskName,
                id: taskId,
            },
            properties: {
                correlationId: taskId,
                replyTo: "",
            },
            body: [args, kwargs, {}],
            sentEvent: null,
        };
        return message;
    }
    /**
     * create json string representing celery task message. used by Client.publish
     *
     * celery protocol reference: https://docs.celeryproject.org/en/latest/internals/protocol.html
     * celery code: https://github.com/celery/celery/blob/4aefccf8a89bffe9dac9a72f2601db1fa8474f5d/celery/app/amqp.py#L307-L464
     *
     * @function createTaskMessage
     *
     * @returns {String} JSON serialized string of celery task message
     */
    asTaskV1(taskId, taskName, args, kwargs) {
        const message = {
            headers: {},
            properties: {
                correlationId: taskId,
                replyTo: "",
            },
            body: {
                task: taskName,
                id: taskId,
                args: args,
                kwargs: kwargs,
            },
            sentEvent: null,
        };
        return message;
    }
    /**
     * createTask
     * @method Client#createTask
     * @param {string} name for task name
     * @returns {Task} task object
     *
     * @example
     * client.createTask('task.add').delay([1, 2])
     */
    createTask(name, options) {
        return new task_1.default(this, name, options);
    }
    /**
     * get AsyncResult by task id
     * @param {string} taskId for task identification.
     * @returns {AsyncResult}
     */
    asyncResult(taskId) {
        return new result_1.AsyncResult(taskId, this.backend);
    }
    sendTask(taskName, args, kwargs, taskId, options) {
        taskId = taskId || uuid_1.v4();
        const message = this.createTaskMessage(taskId, taskName, args, kwargs);
        this.sendTaskMessage(taskName, message, options);
        const result = new result_1.AsyncResult(taskId, this.backend);
        return result;
    }
}
exports.default = Client;
