"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Task {
    /**
     * Asynchronous Task
     * @constructor Task
     * @param {Client} clinet celery client instance
     * @param {string} name celery task name
     * @param {Object} [options]
     * @param {string} [options.queue] queue name
     * @param {string} [options.routingKey] routing key
     */
    constructor(client, name, options = {}) {
        this.client = client;
        this.name = name;
        this.options = options;
    }
    /**
     * @method Task#delay
     *
     * @returns {AsyncResult} the result of client.publish
     *
     * @example
     * client.createTask('task.add').delay(1, 2)
     */
    delay(...args) {
        return this.applyAsync([...args]);
    }
    applyAsync(args, kwargs, options) {
        if (args && !Array.isArray(args)) {
            throw new Error("args is not array");
        }
        if (kwargs && typeof kwargs !== "object") {
            throw new Error("kwargs is not object");
        }
        return this.client.sendTask(this.name, args || [], kwargs || {}, undefined, options || this.options);
    }
}
exports.default = Task;
